@@ -3,7 +3,9 @@ import time
 
 start = time.time()
 cptv_reader = cptv_rs_python_bindings.CptvReader(
-    "../../cptv-codec-rs/tests/fixtures/20201221-748923.cptv")
+    "/home/gp/cacophony/classifier-data/testclip.cptv"
+)
+
 reader = cptv_reader.get_header()
 
 print("version:", reader.version)
@@ -26,18 +28,23 @@ print("camera_serial:", reader.camera_serial)
 
 t0 = None
 frame_num = 0
-
+frame_none = False
 while True:
     frame = cptv_reader.next_frame()
     if frame is not None:
         if t0 is None:
             t0 = frame.time_on
-        frame_num += 1
+        if not frame.background_frame:
+            frame_num += 1
         print(
             f"{frame.time_on - t0} ({frame.time_on}) - ffc: {frame.time_on - frame.last_ffc_time}, min: {frame.pix.min()}, max: {frame.pix.max()}, temp_c: {frame.temp_c}, last_ffc_temp_c: {frame.last_ffc_temp_c}"
         )
     else:
-        break
+        if frame_none:
+            break
+        frame_none = True
+        print("None")
+
 
 end = time.time()
 print(f"{frame_num}, elapsed {end - start}")
